@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Document;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: One JSON Schema document
 
-our $VERSION = '0.518';
+our $VERSION = '0.519';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -18,7 +18,7 @@ use Safe::Isa;
 use Moo;
 use MooX::TypeTiny;
 use MooX::HandlesVia;
-use Types::Standard qw(InstanceOf HashRef Str Dict ArrayRef Enum ClassName);
+use Types::Standard qw(InstanceOf HashRef Str Dict ArrayRef Enum ClassName Undef slurpy);
 use namespace::clean;
 
 extends 'Mojo::JSON::Pointer', 'Moo::Object';
@@ -47,6 +47,7 @@ has resource_index => (
       specification_version => Str,
       # the vocabularies used when evaluating instance data against schema
       vocabularies => ArrayRef[ClassName->where(sub { $_->DOES('JSON::Schema::Modern::Vocabulary') })],
+      slurpy HashRef[Undef],  # no other fields allowed
     ]],
   handles_via => 'Hash',
   handles => {
@@ -103,6 +104,9 @@ has evaluation_configs => (
 around _add_resources => sub {
   my $orig = shift;
   my $self = shift;
+
+  $resource_type->($_[1]) if @_;  # check type of hash value against Dict
+
   foreach my $pair (pairs @_) {
     my ($key, $value) = @$pair;
     if (my $existing = $self->_get_resource($key)) {
@@ -190,7 +194,7 @@ JSON::Schema::Modern::Document - One JSON Schema document
 
 =head1 VERSION
 
-version 0.518
+version 0.519
 
 =head1 SYNOPSIS
 
